summaryrefslogtreecommitdiff
path: root/common
diff options
context:
space:
mode:
Diffstat (limited to 'common')
-rw-r--r--common/test-compat.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/common/test-compat.c b/common/test-compat.c
index 77a0c31..8b5d2e6 100644
--- a/common/test-compat.c
+++ b/common/test-compat.c
@@ -133,8 +133,9 @@ main (int argc,
{
p11_test (test_strndup, "/compat/strndup");
#ifdef OS_UNIX
- /* Don't run this test when under fakeroot */
- if (!getenv ("FAKED_MODE")) {
+ /* Don't run this test when under fakeroot, or the binary is
+ * written under /tmp */
+ if (!getenv ("FAKED_MODE") && strncmp (BUILDDIR, "/tmp/", 5) != 0) {
p11_test (test_getauxval, "/compat/getauxval");
p11_test (test_secure_getenv, "/compat/secure_getenv");
}